<template>
  <div :class='["float-panel",layerControllerVisible ? "active" : ""]' >

    <el-tooltip :popper-class="'map-tooltip'" effect="dark" content="图层" placement="left">
      <div @click="showPanel" class="iconBtn" :class='layerControllerVisible ? "active-button" : ""' v-show="!layerControllerVisible" style="  position: absolute;top:0;left: 0;">
        <img src="@assets/images/map-pages/icon/layer.png" alt="" class="icon">
        <!--        <span class="icon-name">图层</span>-->
      </div>
    </el-tooltip>
    <transition name="animationChange">
      <div :class="'legend-content map-background'" v-show="layerControllerVisible">
        <lc-service-layer></lc-service-layer>
        <button  @click="showPanel" type="button" class="el-button special-button el-button--default el-icon-d-arrow-left"></button>
      </div>
    </transition>
  </div>
</template>

<script>
import '@assets/css/map/magic.min.css'

import iconSetting from '@/assets/images/map-pages/icon/setting.png'
import LcServiceLayer from './modules/LcServiceLayer'

export default {
  name: 'LayerController',
  components: { LcServiceLayer },
  props: {
    preset: {
      type: String,
      default: 'default'
    }
  },
  computed: {
    map () {
      return this.$store.state.map.map
    },
    L () {
      return this.$store.state.map.L
    },
    layerHelper () {
      return this.$store.state.map.layerHelper
    }
  },
  data () {
    return {
      width: '250px',
      isShow: true,
      icons: {
        setting: iconSetting
      },
      layerControllerVisible: false,
      panelSwitch: {
        main: true // 主窗口
      }
    }
  },
  methods: {
    showPanel () {
      this.layerControllerVisible = !this.layerControllerVisible
    },
    switchPanel () {
      this.panelSwitch.main = !this.panelSwitch.main
      if (this.panelSwitch.main) {
        this.width = '250px'
        this.isShow = true
      } else {
        this.width = '0px'
        this.isShow = false
      }
    }
  }
}
</script>

<style lang="less">
  .animationChange-enter-active, .animationChange-leave-active {
    transition: all 0.5s;
  }

  .animationChange-enter, .animationChange-leave-to {
    opacity: 0;
    transform: translateX(-100px);
  }
  .float-panel.active{
    overflow: visible;
  }
.float-panel {
  position: absolute;
  left: 0.14583rem;
  top: 0.73979rem;
  height: auto;
  font-size: 11px;
  z-index: 1000;
  display: flex;
  min-height: 0.28rem;
  min-width: 0.28rem;
  overflow: hidden;
  div {
    color: #00fff6;
  }

  .iconBtn.active{
    display: none;
  }
  .title-border {
    width: 100%;
    height: 28px;
    background: #10488c;
    -webkit-clip-path: polygon(0px 0px, 0px 28px, 230px 28px, 230px 9px, 95px 9px, 86px 0px);
    clip-path: polygon(0px 0px, 0px 28px, 230px 28px, 230px 9px, 95px 9px, 86px 0px);
    position: relative;
  }

  .title-border:before {
    content: "";
    display: block;
    position: absolute;
    width: 6px;
    height: 6px;
    top: 0;
    left: 0;
    background-color: #38c8ef;
  }

  .title-border:after {
    content: "";
    display: block;
    position: absolute;
    width: 6px;
    height: 6px;
    top: 9px;
    right: 0;
    background-color: #38c8ef;
    -webkit-clip-path: polygon(0px 0px, 0px 1px, 5px 1px, 5px 6px, 6px 6px, 6px 0px);
    clip-path: polygon(0px 0px, 0px 1px, 5px 1px, 5px 6px, 6px 6px, 6px 0px);
  }

  .title-text-border {
    width: 30px;
    height: 120px;
    float: left;
    background: #091331;
    // -webkit-clip-path: polygon(1px 1px, 1px 27px, 229px 27px, 229px 10px, 94px 10px, 85px 1px);
    // clip-path: polygon(1px 1px, 1px 27px, 229px 27px, 229px 10px, 94px 10px, 85px 1px);
  }

  .title-icon {
    float: left;
    width: 22px;
    height: 22px;
    margin-top: 4px;
    margin-left: 2px;
    background-image: url(../../assets/images/map-pages/icon/setting.png);
  }

  .title-text {
    width: 25px;
    color: #00d0f9;
    font-weight: bold;
    margin-top: 6px;
    text-align: center;
    font-size: 14px;
    filter: brightness(100%);
    text-shadow: 0 0 5px #00d0f9, 0 0 0 #00d0f9, 0 0 0 #00d0f9, 0 0 0 #0258c5, 0 0 0 #0258c5, 0 0 2px #0258c5, 0 0 5px #0258c5, 0 0 15px #0258c5;
  }

  .title-line {
    display: inline-block;
    width: 120px;
    height: 1px;
    // margin-top: 14px;
    margin-left: 4px;
    background-color: #04527f;
    line-height: 5px;
    vertical-align: middle;
  }

  .title-point {
    display: inline-block;
    width: 5px;
    height: 5px;
    // margin-top: 12px;
    background-color: #04527f;
    line-height: 5px;
    vertical-align: middle;
  }

  .title-button {
    float: right;
    width: 28px;
    height: 28px;
    cursor: pointer;

    :hover {
      font-weight: bold;
      color: white;
    }
  }

  .body-box {
    background-color: rgba(44, 62, 80, 0.6);
    border: 1px solid #10488c;
    margin-top: -1px;
    margin-left: 30px;
    height: auto;
  }
  .switch-head-down {
    transform: rotateX(180deg);
    transform-origin: 50% 50%;
    transition: transform 2s linear 0s;
  }
  select {
    background: transparent;
    margin: 6px;
    border: .5px solid #569EB7;
    width: 150px;
    color: #569EB7;
    padding: 0 16px;
  }
  ::-webkit-scrollbar {
    width: 7px;
    height: 5px !important;
  }

  ::-webkit-scrollbar-thumb {
    /*滚动条里面小方块*/
    border-radius: 10px;
    box-shadow: inset 0 0 5px rgba(0, 0, 0, 0.2);
    background: #0661AE;
    border: 1px solid transparent;
  }

  ::-webkit-scrollbar-track {
    /*滚动条里面轨道*/
    // box-shadow   : inset 0 0 5px rgba(0, 0, 0, 0.2);
    border-radius: 0px;
    background: #0E3565;
  }
  .el-button--default{
   margin-left: 10px;
    padding: 15px 3px;
    background:@background-color;
    color:@color-tool;
    position: absolute;
    top:0;
    right: -26px;
    border-radius: 0.03rem 50% 50% 0.03rem;
  }
  .el-button--default:hover{
    background:@background-color;
  }
  .legend-content{
    width: 250px;
  }
}

</style>
